@@ -35,8 +35,8 @@ get_compressed_sdmx<-function(url=NULL,verbose=FALSE){
                })
     } else {
       tryCatch({utils::download.file(url,temp,dmethod,quiet=TRUE)},
-               error = function(e) {ne<-FALSE},
-               warning = function(w) {ne<-FALSE})
+               error = function(e) {tbc<-FALSE},
+               warning = function(w) {tbc<-FALSE})
     }
     if (tbc) {
       if (grepl("Bulk",url)){
@@ -50,7 +50,7 @@ get_compressed_sdmx<-function(url=NULL,verbose=FALSE){
                    message("get_compressed_sdmx - Error during the unzip of the SDMX file:",'\n',paste(unlist(e),collapse="\n"))
                  },
                  warning = function(w) {
-                   message(get_compressed_sdmx - "Warning by the unzip of the SDMX file:",'\n',paste(unlist(w),collapse="\n"))
+                   message("get_compressed_sdmx - Warning by the unzip of the SDMX file:",'\n',paste(unlist(w),collapse="\n"))
                  })
       } else {
         tryCatch({xml_fajl<-utils::unzip(temp,paste0(fajl,".xml"))},
